<?php

/*
  Module developed for the Open Source Content Management System WebsiteBaker (http://websitebaker.org)
  Copyright (C) 2007 - 2015, Christoph Marti

  LICENCE TERMS:
  This module is free software. You can redistribute it and/or modify it 
  under the terms of the GNU General Public License  - version 2 or later, 
  as published by the Free Software Foundation: http://www.gnu.org/licenses/gpl.html.

  DISCLAIMER:
  This module is distributed in the hope that it will be useful, 
  but WITHOUT ANY WARRANTY; without even the implied warranty of 
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the 
  GNU General Public License for more details.
*/


?>
<!DOCTYPE html>
<html lang="en">
<head>
	<meta charset="utf-8" />
	<title>Sync database with module &quot;Bakery&quot; image directory</title>
	
<?php
// Setup styles to help id errors
echo'
<style type="text/css">
body {
	font-family: Helvetica, non-serif;
	font-size: 13px;
}
.good {
	color: green;
}
.bad {
	color: red;
}
.ok {
	color: blue;
}
.warn {
	color: yellow;
}
</style>';
?>
</head>

<body>
<?php
// Includes
require('../../config.php');
require(WB_PATH.'/framework/class.order.php');

// Get name of the media subfolder that contains the bakery images and thumbs
$img_dir = 'bakery';
if (file_exists(WB_PATH.'/modules/bakery/config.php')) {
	require_once(WB_PATH.'/modules/bakery/config.php');
}

// Database
global $database;

// Counter
$counter = 0;

// Title
echo '<h1 >Sync database with module Bakery image directory</h1>';
echo '<h2 >Searching for all images in the Bakery image directory</h2>';


// GET ALL IMAGES OF THE BAKERY IMAGE DIRECTORY
// ********************************************

// Prepare image directory url and path
$img_url = WB_URL.MEDIA_DIRECTORY.'/'.$img_dir.'/images/';
$img_dir = WB_PATH.MEDIA_DIRECTORY.'/'.$img_dir.'/images/';

// Initialize var
$image_files = array();

// Check if the bakery image directory exists
if (is_dir($img_dir)) {

	// Open the image directory
	$d = dir($img_dir);
	// Get the subdirectories for every item
	while (false !== ($subdir = $d->read())) {

		// Skip index file and pointers
		if (strpos($subdir, '.php') !== false || substr($subdir, 0, 1) == ".") {
			continue;
		}

		// Get all images of current item
		$img_subdir = $img_dir.$subdir.'/';
		$item_id    = str_replace('item', '', $subdir);
		if (is_dir($img_subdir)) {

			// Open the image directory then loop through its content
			$sd = dir($img_subdir);

			// Get the item images
			while (false !== ($image_file = $sd->read())) {

				// Skip index file and pointers
				if (strpos($image_file, '.php') !== false || substr($image_file, 0, 1) == ".") {
					continue;
				}

				// Make array of all items with subarray of image names
				$image_files[$item_id][] = $image_file;
				$counter++;
			}
			$sd->close();
		}
	}
	$d->close();
}
else {
	die('<h4 class="bad">The Bakery image directory does not exist:<br>'.$img_dir.'.</h4>');
}

// Num of images
echo 'Found <b>'.$counter.' images</b> in the Bakery image directory:<br><code>'.$img_dir.'</code>';




// UPDATE THE DATABASE TABLE mod_bakery_images
// *******************************************

// Title
echo '<h2 style="margin-top: 2.6em;">Updating database table '.TABLE_PREFIX.'mod_bakery_images</h2>';

// Initialize class order
$img_order = new order(TABLE_PREFIX.'mod_bakery_images', 'position', 'img_id', 'item_id');

// Get item id
foreach ($image_files as $item_id => $filenames) {

	// Item id
	echo '<h3 style="margin-top: 2em;">Item ID = '.$item_id.'</h3>';

	// Get image top position for this item
	$top_position = $database->get_one("SELECT MAX(`position`) AS `top_position` FROM ".TABLE_PREFIX."mod_bakery_images WHERE `item_id` = '$item_id'");
	// Increment position (db function returns NULL if this item has no image yet)
	$top_position = intval($top_position) + 1;

	// Get the file names and update database
	foreach ($filenames as $filename) {

		// Check if the image is in the db
		$insert_img = $database->get_one("SELECT `filename` FROM ".TABLE_PREFIX."mod_bakery_images WHERE `item_id` = '$item_id' AND `filename` = '$filename'");

		// Link to the image
		$link = '<a href="'.$img_url.'item'.$item_id.'/'.$filename.'" title="'.$filename.'" target="_blank">'.$filename.'</a>';

		// If image is not found, insert image data into the db
		if ($insert_img === NULL) {
			if ($database->query("INSERT INTO ".TABLE_PREFIX."mod_bakery_images (`item_id`, `filename`, `position`) VALUES ('$item_id', '$filename', '$top_position')")) {
				$top_position++;
				echo '<span class="good">Added image '.$link.' to the database successfully.</span><br>';
			} else {
				echo '<span class="bad">'.$database->get_error().'</span><br>';
			}
		} else {
			echo '<span class="ok">Image '.$link.' is already saved in database.</span><br>';
		}
	}

	// Clean up image order
	$img_order->clean($item_id);
}
?>

<h2 style="margin-top: 2.6em;">In order to complete the image settings go to the Bakery backend and edit the newly added items:</h2>
<ol>
	<li>Please enter your image data like title and alt attributes and order the images using the up- and down-arrows.</li>
	<li>The alt attribute is mandatory.</li>
	<li>If you set a title and no alt attribute, the title will be used as alt attribute as well.</li>
	<li>The image at the top position (position 1) will be used as the main image.</li>
	<li>If you enter a image caption, the image will be wrapped in a &lt;div&gt; container and the image will be followed after a &lt;br&gt; by your caption.</li>
	<li>The item attribute generates a unique id like <code>mod_bakery_img_attrXX_f</code> where the <code>XX</code> stands for the image attribute id. This can be used for any JavaScript actions depending on the selected option attribute. Eg. change main image depending on selected item option.</li>
	<li>Not used images can be deactivated or deleted in the backend.</li>
</ol>

</body>
</html>